# Prerequisites

* You need:

  * [CPython 2.7.x.](www.python.org/downloads)
  * [virtualenv](https://pypi.org/project/virtualenv)

* Other Python versions resp. implementations are currently not supported.
